@@ -28,9 +28,6 @@ class Partner:
         sponsor_id,
         coop_candidate,
         member,
-        sponsorship_code,
-        sponsees_max,
-        sponsees_number,
         addresses,
         banned_actions,
         **kwargs
@@ -52,9 +49,6 @@ class Partner:
         self.coop_agreement_code = coop_agreement_code
         self.coop_candidate = coop_candidate
         self.member = member
-        self.sponsorship_code = sponsorship_code
-        self.sponsees_max = sponsees_max
-        self.sponsees_number = sponsees_number
         self.addresses = []
         for address in addresses:
             self.addresses.append(Address(**address))
